@@ -211,6 +211,9 @@ void __Image()
         .def("roll", (void (Magick::Image::*)(const unsigned int, const unsigned int) )&Magick::Image::roll)
 #endif
         .def("rotate", &Magick::Image::rotate)
+#ifdef PGMAGICK_LIB_GRAPHICSMAGICK_1_3_19_OVER
+        .def("thumbnail", &Magick::Image::thumbnail)
+#endif
         .def("sample", &Magick::Image::sample)
         .def("scale", &Magick::Image::scale)
         .def("segment", &Magick::Image::segment, Magick_Image_segment_overloads_0_2())
@@ -358,6 +361,7 @@ void __Image()
         .def("fillPattern", (void (Magick::Image::*)(const Magick::Image&) )&Magick::Image::fillPattern)
         .def("fillPattern", (Magick::Image (Magick::Image::*)() const)&Magick::Image::fillPattern)
         .def("filterType", (void (Magick::Image::*)(const Magick::FilterTypes) )&Magick::Image::filterType)
+        .def("filterType", (Magick::FilterTypes (Magick::Image::*)(void) const)&Magick::Image::filterType)
         .def("font", (void (Magick::Image::*)(const std::string&) )&Magick::Image::font)
         .def("font", (std::string (Magick::Image::*)() const)&Magick::Image::font)
         .def("fontPointsize", (void (Magick::Image::*)(const double) )&Magick::Image::fontPointsize)
